@@ -317,9 +317,7 @@ def _build_response(
 
 
 def sync_detailed(
-    table_id: int,
-    *,
-    client: AuthenticatedClient,
+    table_id: int, *, client: AuthenticatedClient, httpx_client=None
 ) -> Response[
     Union[
         ListDatabaseTableFieldsResponse400,
@@ -370,7 +368,7 @@ def sync_detailed(
         client=client,
     )
 
-    response = httpx.request(
+    response = (httpx_client or httpx).request(
         verify=client.verify_ssl,
         **kwargs,
     )
